-- ------------------------------------------------------------
-- ------------------------------------------------------------
-- SAR TABLE, INDEX, AND TABLESPACE CREATION TEMPLATE
-- ------------------------------------------------------------
-- This script is a template for creating the schemas, tables, 
-- indexes, and constraints required for SAR for a MySQL AML
-- installation.
--
-- This script is only a template.  It must be customized
-- to the physical environment and volume of data expected. 
--
-- Indexes may be added or removed as desired for performance reasons, 
-- however, modifications to the ETL process might be necessary to 
-- accomodate such changes, since it is often necessary to drop and
-- rebuild indexes during ETL for performance reasons.
--
-- This script assumes that the default storage engine has been
-- set to the desired storage engine. SAS recommends the InnoDB
-- engine.
-- 
-- This script must be run as an account with DBA privileges.
-- ------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

USE `AMLCTR`;

CREATE TABLE AMLCTR.ACTIVITY_TYPE_CODES
(
	ACTIVITY_TYPE         CHAR(1) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (ACTIVITY_TYPE,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_20 ON ACTIVITY_TYPE_CODES
(
	ACTIVITY_TYPE,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.BATCH_SEQ
(
	SAR_ID                BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	SEQ_NUMBER            CHAR(18) NOT NULL,
	FILE_CREATION_DATE    DATETIME NULL,
	BATCH_FILE_NAME       VARCHAR(40) NULL,
	UPDATE_DATE           CHAR(18) NOT NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (SAR_ID,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_12 ON BATCH_SEQ
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_12 ON BATCH_SEQ
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.BRANCH
(
	INSTITUTION_ID        BIGINT NOT NULL,
	BRANCH_SEQ            BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	BRANCH_ADDRESS        VARCHAR(35) NULL,
	BRANCH_CITY           VARCHAR(25) NULL,
	BRANCH_STATE          CHAR(2) NULL,
	BRANCH_ZIP            CHAR(9) NULL,
	BRANCH_CODE           CHAR(7) NULL,
	 PRIMARY KEY (INSTITUTION_ID,BRANCH_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_14 ON BRANCH
(
	INSTITUTION_ID,
	BRANCH_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_14 ON BRANCH
(
	INSTITUTION_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.COUNTRY_CODES
(
	COUNTRY               CHAR(2) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	COUNTRY_NAME          VARCHAR(45) NULL,
	 PRIMARY KEY (COUNTRY,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_15 ON COUNTRY_CODES
(
	COUNTRY,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.ENFORCEMENT_CODES
(
	ENFORCEMENT           CHAR(1) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (ENFORCEMENT,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_22 ON ENFORCEMENT_CODES
(
	ENFORCEMENT,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.GOVT_ID_CODES
(
	GOVT_ID               CHAR(1) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (GOVT_ID,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_19 ON GOVT_ID_CODES
(
	GOVT_ID,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.INSIDE_RELATIONSHIP_CODES
(
	INSIDE_RELATIONSHIP   CHAR(2) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (INSIDE_RELATIONSHIP,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_18 ON INSIDE_RELATIONSHIP_CODES
(
	INSIDE_RELATIONSHIP,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.INSTITUTION
(
	INSTITUTION_ID        BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	NAME                  VARCHAR(35) NULL,
	EIN                   CHAR(9) NULL,
	ADDRESS               VARCHAR(35) NULL,
	CITY                  VARCHAR(25) NULL,
	STATE                 CHAR(2) NULL,
	ZIP                   CHAR(9) NULL,
	PRIMARY_REGULATOR     CHAR(1) NULL,
	CEN_REG_NBR           CHAR(11) NULL,
	SEC_ID                CHAR(9) NULL,
	NFA_ID                CHAR(8) NULL,
	TYPE_INSTITUTION      VARCHAR(27) NULL,
	CONTACT_LNAME         VARCHAR(20) NULL,
	CONTACT_FNAME         VARCHAR(20) NULL,
	CONTACT_MI            CHAR(1) NULL,
	CONTACT_TITLE         VARCHAR(25) NULL,
	CONTACT_WORK_PHONE    CHAR(10) NULL,
	TRANSMITTER_FLAG      CHAR(1) NULL,
	TRANSMITTER_CONTROL_CODE  CHAR(8) NULL,
	 PRIMARY KEY (INSTITUTION_ID,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_13 ON INSTITUTION
(
	INSTITUTION_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.INSTRUMENT_TYPE_CODES
(
	INST_TYPE             CHAR(1) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (INST_TYPE,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_21 ON INSTRUMENT_TYPE_CODES
(
	INST_TYPE,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.REGULATOR_CODES
(
	PRIMARY_REGULATOR     CHAR(1) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NOT NULL,
	 PRIMARY KEY (PRIMARY_REGULATOR,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_23 ON REGULATOR_CODES
(
	PRIMARY_REGULATOR,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.RELATIONSHIP_CODES
(
	RELATIONSHIP_CODE     CHAR(2) NOT NULL,
	SAR_TYPE              CHAR(2) NOT NULL,
	DESCRIPTION           VARCHAR(40) NULL,
	 PRIMARY KEY (RELATIONSHIP_CODE,SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_17 ON RELATIONSHIP_CODES
(
	RELATIONSHIP_CODE,
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.SAR_ALERTS
(
	SAR_ID                BIGINT NOT NULL,
	ALERT_ID              BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	 PRIMARY KEY (SAR_ID,ALERT_ID,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_7 ON SAR_ALERTS
(
	SAR_ID,
	ALERT_ID,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_7 ON SAR_ALERTS
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_CNTL
(
	SAR_ID                BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	SAR_TYPE              CHAR(2) NOT NULL,
	SAR_DESCRIPTION       VARCHAR(60) NULL,
	SAR_STATUS            CHAR(2) NOT NULL,
	CORRECTION            CHAR(1) NULL,
	NUMBER_SUSPECTS       NUMERIC(8,0) NULL,
	DATE_FILED            DATETIME NULL,
	CREATE_USER           VARCHAR(35) NULL,
	CREATE_DATE           DATETIME NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	ORIGINAL_SAR_ID       NUMERIC(15) NULL,
	ACTIVITY_TYPE_CODE    CHAR(3) NULL,
	 PRIMARY KEY (SAR_ID,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_1 ON SAR_CNTL
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_1 ON SAR_CNTL
(
	SAR_TYPE
)
;



CREATE INDEX XIF2E_1 ON SAR_CNTL
(
	SAR_STATUS
)
;



CREATE TABLE AMLCTR.SAR_CONTACT
(
	SAR_ID                BIGINT NOT NULL,
	CONTACT_SEQ           BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	LNAME                 VARCHAR(20) NULL,
	FNAME                 VARCHAR(20) NULL,
	MI                    CHAR(1) NULL,
	CONTACT_TITLE         VARCHAR(25) NULL,
	WORK_PHONE            CHAR(10) NULL,
	DATE_SUBMIT           DATETIME NULL,
	AGENCY                VARCHAR(35) NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (SAR_ID,CONTACT_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_10 ON SAR_CONTACT
(
	SAR_ID,
	CONTACT_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_10 ON SAR_CONTACT
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_INFO
(
	SAR_ID                BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	ACCT_NBR1             VARCHAR(22) NULL,
	ACCT1_ACTIVE          CHAR(1) NULL,
	ACCT_NBR2             VARCHAR(22) NULL,
	ACCT2_ACTIVE          CHAR(1) NULL,
	ACCT_NBR3             VARCHAR(22) NULL,
	ACCT3_ACTIVE          CHAR(1) NULL,
	ACCT_NBR4             VARCHAR(22) NULL,
	ACCT4_ACTIVE          CHAR(1) NULL,
	FROM_DATE             DATETIME NULL,
	TO_DATE               DATETIME NULL,
	AMOUNT                NUMERIC(15,2) NULL,
	AMT_LOSS              DECIMAL(15,2) NULL,
	AMT_RECOVERED         DECIMAL(15,2) NULL,
	MATERIAL_IMPACT       CHAR(1) NULL,
	BONDING_NOTIFY        CHAR(1) NULL,
	INST_TYPE             VARCHAR(25) NULL,
	CUSIP_1               CHAR(12) NULL,
	CUSIP_2               CHAR(12) NULL,
	CUSIP_3               CHAR(12) NULL,
	CUSIP_4               CHAR(12) NULL,
	CUSIP_5               CHAR(12) NULL,
	CUSIP_6               CHAR(12) NULL,
	COMMODITY_TYPE        VARCHAR(20) NULL,
	INSTRUMENT_DESC       VARCHAR(20) NULL,
	MARKET_TRADED         CHAR(4) NULL,
	ACTIVITY_TYPE         VARCHAR(20) NULL,
	ACTIVITY_OTHER        VARCHAR(40) NULL,
	ENFORCEMENT           VARCHAR(18) NULL,
	OTH_ENFORCEMENT       VARCHAR(35) NULL,
	ENF_CONTACT1          VARCHAR(35) NULL,
	ENF_PHONE1            VARCHAR(10) NULL,
	ENF_CONTACT2          VARCHAR(35) NULL,
	ENF_PHONE2            VARCHAR(10) NULL,
	ENF_DATE              DATETIME NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (SAR_ID,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_2 ON SAR_INFO
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_2 ON SAR_INFO
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_INSTITUTION
(
	SAR_ID                BIGINT NOT NULL,
	INSTITUTION_SEQ       BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	NAME                  VARCHAR(35) NULL,
	EIN                   CHAR(9) NULL,
	ADDRESS               VARCHAR(35) NULL,
	CITY                  VARCHAR(25) NULL,
	STATE                 CHAR(2) NULL,
	ZIP                   CHAR(9) NULL,
	DATE_CLOSED           DATETIME NULL,
	PRIMARY_REGULATOR     CHAR(1) NULL,
	BRANCH_ADDRESS        VARCHAR(35) NULL,
	BRANCH_CITY           VARCHAR(35) NULL,
	BRANCH_STATE          CHAR(2) NULL,
	BRANCH_ZIP            CHAR(9) NULL,
	BRANCH_CODE           CHAR(7) NULL,
	MULTIPLE_BRANCHES     CHAR(1) NULL,
	CEN_REG_NBR           CHAR(11) NULL,
	SEC_ID                CHAR(9) NULL,
	NFA_ID                CHAR(8) NULL,
	RPT_COORD             CHAR(1) NULL,
	TYPE_INST             VARCHAR(27) NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (SAR_ID,INSTITUTION_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_8 ON SAR_INSTITUTION
(
	SAR_ID,
	INSTITUTION_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_8 ON SAR_INSTITUTION
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_NAMES
(
	SAR_ID                BIGINT NOT NULL,
	NAME_SEQ              BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	LNAME                 VARCHAR(20) NULL,
	FNAME                 VARCHAR(20) NULL,
	MI                    CHAR(1) NULL,
	AKA                   VARCHAR(35) NULL,
	SSN_EIN               CHAR(9) NULL,
	DOB                   DATETIME NULL,
	OCCUPATION            VARCHAR(30) NULL,
	ADMISSION_CONFESSION  CHAR(1) NULL,
	ADDRESS               VARCHAR(35) NULL,
	CITY                  VARCHAR(25) NULL,
	STATE                 CHAR(2) NULL,
	ZIP                   CHAR(9) NULL,
	COUNTRY               CHAR(2) NULL,
	EMAIL                 VARCHAR(60) NULL,
	RELATIONSHIP_CODE     CHAR(4) NULL,
	RELATIONSHIP_OTHER    VARCHAR(40) NULL,
	INSIDE_RELATIONSHIP   CHAR(2) NULL,
	TERMINATION_DATE      DATETIME NULL,
	GOVT_ID               CHAR(1) NULL,
	ID_OTHER              VARCHAR(40) NULL,
	ID_NBR                VARCHAR(22) NULL,
	ID_ORIGIN             CHAR(2) NULL,
	WORK_PHONE            CHAR(10) NULL,
	HOME_PHONE            CHAR(10) NULL,
	ASSOCIATED            CHAR(1) NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	PARTY_TAX_ID          VARCHAR(50) NULL,
	CITIZENSHIP_COUNTRY_CODE  CHAR(3) NULL,
	STREET_ADDRESS_TEXT   VARCHAR(255) NULL,
	MAILING_ADDRESS_TEXT  VARCHAR(255) NULL,
	INTERNAL_RELATIONSHIP_TEXT  VARCHAR(1024) NULL,
	EXTERNAL_RELATIONSHIP_TEXT  VARCHAR(1024) NULL,
	 PRIMARY KEY (SAR_ID,NAME_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_3 ON SAR_NAMES
(
	SAR_ID,
	NAME_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_3 ON SAR_NAMES
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_NARATIVE
(
	SAR_ID                BIGINT NOT NULL,
	NARATIVE_SEQ          BIGINT NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	NARATIVE              LONG VARCHAR NOT NULL,
	UPDATE_DATE           DATETIME NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (SAR_ID,NARATIVE_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKE_4 ON SAR_NARATIVE
(
	SAR_ID,
	NARATIVE_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1E_4 ON SAR_NARATIVE
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_STATUS_CODES
(
	SAR_STATUS            CHAR(2) NOT NULL,
	SAR_STATUS_DSCR       VARCHAR(45) NOT NULL,
	 PRIMARY KEY (SAR_STATUS)
)
;



CREATE UNIQUE INDEX XPKE_6 ON SAR_STATUS_CODES
(
	SAR_STATUS
)
;



CREATE TABLE AMLCTR.SAR_TRANSACTION
(
	SAR_ID                BIGINT NOT NULL,
	TRANSACTION_SEQ       NUMERIC(15) NOT NULL,
	SEGMENT_ID            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	TRANSACTION_TYPE_DESC  VARCHAR(35) NULL,
	TRANSACTION_DATE_DESC  VARCHAR(35) NULL,
	BRANCH_NUMBER         VARCHAR(25) NULL,
	BRANCH_NAME           VARCHAR(35) NULL,
	CURRENCY_AMT_IN_TXN_CCY  VARCHAR(35) NULL,
	TRANSACTION_CURRENCY_CODE  CHAR(3) NULL,
	PURPOSE_DESC          VARCHAR(1024) NULL,
	SOURCE_OF_FUNDS_DESC  VARCHAR(1024) NULL,
	ACCOUNT_NUMBER        VARCHAR(50) NULL,
	COMMENT_TEXT          VARCHAR(1024) NULL,
	 PRIMARY KEY (SAR_ID,TRANSACTION_SEQ,SEGMENT_ID)
)
;



CREATE UNIQUE INDEX XPKSAR_TRANSACTION ON SAR_TRANSACTION
(
	SAR_ID,
	TRANSACTION_SEQ,
	SEGMENT_ID
)
;



CREATE INDEX XIF1SAR_TRANSACTION ON SAR_TRANSACTION
(
	SAR_ID,
	SEGMENT_ID
)
;



CREATE TABLE AMLCTR.SAR_TYPE_CODES
(
	SAR_TYPE              CHAR(2) NOT NULL,
	SAR_TYPE_DSCR         VARCHAR(45) NOT NULL,
	SAR_TYPE_SHORT_DSCR   VARCHAR(35) NULL,
	ACTIVE_FLAG           CHAR(1) NULL,
	 PRIMARY KEY (SAR_TYPE)
)
;



CREATE UNIQUE INDEX XPKE_5 ON SAR_TYPE_CODES
(
	SAR_TYPE
)
;



CREATE TABLE AMLCTR.STATE_CODES
(
	STATE                 CHAR(2) NOT NULL,
	COUNTRY               CHAR(2) NOT NULL,
	STATE_NAME            VARCHAR(40) NOT NULL,
	SAR_TYPE              CHAR(2) NULL,
	 PRIMARY KEY (STATE,COUNTRY)
)
;



CREATE UNIQUE INDEX XPKE_16 ON STATE_CODES
(
	STATE,
	COUNTRY
)
;



ALTER TABLE AMLCTR.BATCH_SEQ
	ADD FOREIGN KEY R_10 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.BRANCH
	ADD FOREIGN KEY R_11 (INSTITUTION_ID,SEGMENT_ID) REFERENCES AMLCTR.INSTITUTION(INSTITUTION_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_ALERTS
	ADD FOREIGN KEY R_3 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_CNTL(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_CNTL
	ADD FOREIGN KEY R_4 (SAR_TYPE) REFERENCES AMLCTR.SAR_TYPE_CODES(SAR_TYPE)
;


ALTER TABLE AMLCTR.SAR_CNTL
	ADD FOREIGN KEY R_5 (SAR_STATUS) REFERENCES AMLCTR.SAR_STATUS_CODES(SAR_STATUS)
;



ALTER TABLE AMLCTR.SAR_CONTACT
	ADD FOREIGN KEY R_9 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_INFO
	ADD FOREIGN KEY R_2 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_CNTL(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_INSTITUTION
	ADD FOREIGN KEY R_8 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_NAMES
	ADD FOREIGN KEY R_6 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_NARATIVE
	ADD FOREIGN KEY R_7 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_TRANSACTION
	ADD FOREIGN KEY R_12 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


SET FOREIGN_KEY_CHECKS = 1;

create view BANK1KCTR.ACTIVITY_TYPE_CODES as select * from AMLCTR.ACTIVITY_TYPE_CODES;
create view BANK1KCTR.BATCH_SEQ as select * from AMLCTR.BATCH_SEQ where segment_id='BANK1KCTR';
create view BANK1KCTR.BRANCH as select * from AMLCTR.BRANCH where segment_id='BANK1KCTR';
create view BANK1KCTR.COUNTRY_CODES as select * from AMLCTR.COUNTRY_CODES;
create view BANK1KCTR.ENFORCEMENT_CODES as select * from AMLCTR.ENFORCEMENT_CODES;
create view BANK1KCTR.GOVT_ID_CODES as select * from AMLCTR.GOVT_ID_CODES;
create view BANK1KCTR.INSIDE_RELATIONSHIP_CODES as select * from AMLCTR.INSIDE_RELATIONSHIP_CODES;
create view BANK1KCTR.INSTITUTION as select * from AMLCTR.INSTITUTION where segment_id='BANK1KCTR';
create view BANK1KCTR.INSTRUMENT_TYPE_CODES as select * from AMLCTR.INSTRUMENT_TYPE_CODES;
create view BANK1KCTR.REGULATOR_CODES as select * from AMLCTR.REGULATOR_CODES;
create view BANK1KCTR.RELATIONSHIP_CODES as select * from AMLCTR.RELATIONSHIP_CODES;
create view BANK1KCTR.SAR_ALERTS as select * from AMLCTR.SAR_ALERTS where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_CNTL as select * from AMLCTR.SAR_CNTL where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_CONTACT as select * from AMLCTR.SAR_CONTACT where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_INFO as select * from AMLCTR.SAR_INFO where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_INSTITUTION as select * from AMLCTR.SAR_INSTITUTION where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_NAMES as select * from AMLCTR.SAR_NAMES where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_NARATIVE as select * from AMLCTR.SAR_NARATIVE where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_STATUS_CODES as select * from AMLCTR.SAR_STATUS_CODES;
create view BANK1KCTR.SAR_TRANSACTION as select * from AMLCTR.SAR_TRANSACTION where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_TYPE_CODES as select * from AMLCTR.SAR_TYPE_CODES;
create view BANK1KCTR.STATE_CODES as select * from AMLCTR.STATE_CODES;
